==> react-tcf-second-layer-1.10.0.tgz: package/lib/components/tcf-secondLayer-vendors-user-decision/index.js <==
import React, { useState } from 'react';
import SuiSwitch from '@s-ui/react-atom-switch';
export default function TcfSecondLayerVendorsUserDecision(_ref) {
  var onConsentChange = _ref.onConsentChange,
      baseClass = _ref.baseClass,
      info = _ref.info,
      consentValue = _ref.consentValue,
      _ref$hasConsent = _ref.hasConsent,
      hasConsent = _ref$hasConsent === void 0 ? true : _ref$hasConsent,
      expandedContent = _ref.expandedContent,
      i18n = _ref.i18n;

  var _useState = useState(false),
      expanded = _useState[0],
      setExpanded = _useState[1];

  var handleItemClick = function handleItemClick() {
    setExpanded(!expanded);
  };

  var Switchs = function Switchs() {
    return /*#__PURE__*/React.createElement("div", {
      className: baseClass + "-switchs"
    }, hasConsent && /*#__PURE__*/React.createElement(SuiSwitch, {
      type: "single",
      name: "groupItem",
      value: consentValue,
      label: i18n.CONSENT_COPY,
      onToggle: function onToggle() {
        return onConsentChange(consentValue);
      }
    }));
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: baseClass + "-container"
  }, /*#__PURE__*/React.createElement("div", {
    className: baseClass + "-container-clicklable",
    onClick: handleItemClick
  }, /*#__PURE__*/React.createElement("p", {
    className: baseClass + "-title"
  }, info.name), /*#__PURE__*/React.createElement("p", {
    className: baseClass + "-text"
  }, info.description), /*#__PURE__*/React.createElement("p", {
    className: baseClass + "-link",
    onClick: function onClick() {
      return setExpanded(!expanded);
    }
  }, expanded ? i18n.SECOND_LAYER.READ_LESS : i18n.SECOND_LAYER.READ_MORE)), hasConsent ? /*#__PURE__*/React.createElement(Switchs, null) : null), expanded && /*#__PURE__*/React.createElement("div", {
    className: baseClass + "-container--expanded"
  }, expandedContent({
    info: info,
    baseClass: baseClass
  })));
}
TcfSecondLayerVendorsUserDecision.defaultProps = {
  hasConsent: true
};

==> react-tcf-second-layer-1.12.0.tgz: package/lib/components/tcf-secondLayer-vendors-user-decision/index.js <==
import React, { useState } from 'react';
import AtomSwitch from '@s-ui/react-atom-switch';
import Button from '@s-ui/react-atom-button';
export default function TcfSecondLayerVendorsUserDecision(_ref) {
  var onConsentChange = _ref.onConsentChange,
      baseClass = _ref.baseClass,
      info = _ref.info,
      consentValue = _ref.consentValue,
      _ref$hasConsent = _ref.hasConsent,
      hasConsent = _ref$hasConsent === void 0 ? true : _ref$hasConsent,
      expandedContent = _ref.expandedContent,
      i18n = _ref.i18n;

  var _useState = useState(false),
      expanded = _useState[0],
      setExpanded = _useState[1];

  var Switchs = function Switchs() {
    return hasConsent && /*#__PURE__*/React.createElement(AtomSwitch, {
      type: "single",
      name: "groupItem",
      value: consentValue,
      label: i18n.CONSENT_COPY,
      onToggle: function onToggle() {
        return onConsentChange(consentValue);
      }
    });
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: baseClass + " " + baseClass + "--vendors"
  }, /*#__PURE__*/React.createElement("div", {
    className: baseClass + "-texts"
  }, /*#__PURE__*/React.createElement("h6", {
    className: baseClass + "-title"
  }, info.name), /*#__PURE__*/React.createElement("p", null, info.description), expanded && expandedContent({
    info: info,
    baseClass: baseClass
  }), /*#__PURE__*/React.createElement(Button, {
    design: "link",
    onClick: function onClick() {
      return setExpanded(!expanded);
    }
  }, expanded ? i18n.SECOND_LAYER.READ_LESS : i18n.SECOND_LAYER.READ_MORE)), hasConsent ? /*#__PURE__*/React.createElement(Switchs, null) : null));
}
TcfSecondLayerVendorsUserDecision.defaultProps = {
  hasConsent: true
};
